Package: fobitools
Title: Tools for Manipulating the FOBI Ontology
Version: 1.20.0
Authors@R: 
    c(person(given = "Pol",
             family = "Castellano-Escuder",
             role = c("aut", "cre"),
             email = "polcaes@gmail.com",
             comment = c(ORCID = "0000-0001-6466-877X")),
      person(given = "Alex",
             family = "Sánchez-Pla",
             role = "aut",
             email = "asanchez@ub.edu",
             comment = c(ORCID = "0000-0002-8673-7737"))
             )
Description: A set of tools for interacting with the Food-Biomarker Ontology (FOBI). A collection 
    of basic manipulation tools for biological significance analysis, graphs, and text mining 
    strategies for annotating nutritional data.
License: GPL-3
Encoding: UTF-8
LazyData: true
biocViews: MassSpectrometry, Metabolomics, Software, Visualization,
        BiomedicalInformatics, GraphAndNetwork, Annotation,
        Cheminformatics, Pathways, GeneSetEnrichment
Imports: clisymbols, crayon, dplyr, fgsea, ggplot2, ggraph, magrittr,
        ontologyIndex, purrr, RecordLinkage, stringr, textclean,
        tictoc, tidygraph, tidyr, vroom
Suggests: BiocStyle, covr, ggrepel, kableExtra, knitr,
        metabolomicsWorkbenchR, POMA, rmarkdown, rvest,
        SummarizedExperiment, testthat (>= 2.3.2), tidyverse
RoxygenNote: 7.3.2
Depends: R (>= 4.1)
URL: https://github.com/pcastellanoescuder/fobitools/
BugReports: https://github.com/pcastellanoescuder/fobitools/issues
VignetteBuilder: knitr
git_url: https://git.bioconductor.org/packages/fobitools
git_branch: RELEASE_3_23
git_last_commit: 7bd39a6
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 22:09:02 UTC; biocbuild
Author: Pol Castellano-Escuder [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-6466-877X>),
  Alex Sánchez-Pla [aut] (ORCID: <https://orcid.org/0000-0002-8673-7737>)
Maintainer: Pol Castellano-Escuder <polcaes@gmail.com>
